#[non_exhaustive]pub enum ParseHotkeyError {
Empty,
EmptySegment,
UnknownToken(String),
MissingKey,
MultipleKeys,
}Expand description
Error returned when parsing a hotkey or key from a string fails.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
The input string was empty.
EmptySegment
A segment between + separators was empty (e.g., "Ctrl++A").
UnknownToken(String)
A token could not be recognized as a key or modifier.
MissingKey
The hotkey contained only modifiers with no trigger key.
MultipleKeys
The hotkey contained more than one non-modifier key.