pub struct LayerOptions { /* private fields */ }Expand description
Per-layer behavioral options.
Implementations
Sourceimpl LayerOptions
impl LayerOptions
Sourcepub const fn oneshot(&self) -> Option<usize>
pub const fn oneshot(&self) -> Option<usize>
If set, automatically pop the layer after this many keypresses.
Sourcepub const fn unmatched(&self) -> UnmatchedKeys
pub const fn unmatched(&self) -> UnmatchedKeys
Whether unmatched keys are consumed or fall through.
Sourcepub const fn timeout(&self) -> Option<Duration>
pub const fn timeout(&self) -> Option<Duration>
If set, automatically pop the layer after this duration of inactivity.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Human-readable label for this layer, used for overlay grouping.
Sourcepub const fn with_unmatched(self, behavior: UnmatchedKeys) -> Self
pub const fn with_unmatched(self, behavior: UnmatchedKeys) -> Self
Set unmatched key behavior.